@@ -1,19 +1,13 @@
 <?php
+
 // Icinga Reporting | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\Reporting {
 
-    use Icinga\Application\Version;
-
     /** @var \Icinga\Application\Modules\Module $this */
 
     $this->provideCssFile('system-report.css');
 
-    if (version_compare(Version::VERSION, '2.9.0', '<')) {
-        $this->provideJsFile('vendor/flatpickr.min.js');
-        $this->provideCssFile('vendor/flatpickr.min.css');
-    }
-
     $this->menuSection(N_('Reporting'))->add(N_('Reports'), array(
         'url' => 'reporting/reports',
     ));
